@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/kinesis-video-archived-media/KinesisVideoArchivedMedia_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kinesis-video-archived-media/KinesisVideoArchivedMedia_EXPORTS.h>
 
-namespace Aws
-{
-namespace KinesisVideoArchivedMedia
-{
-namespace Model
-{
-  enum class ContainerFormat
-  {
-    NOT_SET,
-    FRAGMENTED_MP4,
-    MPEG_TS
-  };
+namespace Aws {
+namespace KinesisVideoArchivedMedia {
+namespace Model {
+enum class ContainerFormat { NOT_SET, FRAGMENTED_MP4, MPEG_TS };
 
-namespace ContainerFormatMapper
-{
+namespace ContainerFormatMapper {
 AWS_KINESISVIDEOARCHIVEDMEDIA_API ContainerFormat GetContainerFormatForName(const Aws::String& name);
 
 AWS_KINESISVIDEOARCHIVEDMEDIA_API Aws::String GetNameForContainerFormat(ContainerFormat value);
-} // namespace ContainerFormatMapper
-} // namespace Model
-} // namespace KinesisVideoArchivedMedia
-} // namespace Aws
+}  // namespace ContainerFormatMapper
+}  // namespace Model
+}  // namespace KinesisVideoArchivedMedia
+}  // namespace Aws
